summaryrefslogtreecommitdiff
path: root/gdk/gdkeventsprivate.h
diff options
context:
space:
mode:
authorBenjamin Otte <otte@redhat.com>2018-05-29 20:49:41 +0200
committerBenjamin Otte <otte@redhat.com>2018-06-18 23:49:52 +0200
commitc67fb578814f4a2063203367a26189ddf0499531 (patch)
tree426195dd7a6bbab3d03b8df605c12e7334d6a7a5 /gdk/gdkeventsprivate.h
parent81171cc0a21fd814d4856dca03cfd11cff8e47d9 (diff)
downloadgtk+-c67fb578814f4a2063203367a26189ddf0499531.tar.gz
events: Make GdkEventDND have a GdkDrop member
... instead of a GdkDragContext.
Diffstat (limited to 'gdk/gdkeventsprivate.h')
-rw-r--r--gdk/gdkeventsprivate.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gdk/gdkeventsprivate.h b/gdk/gdkeventsprivate.h
index d2cc705c07..d79beab255 100644
--- a/gdk/gdkeventsprivate.h
+++ b/gdk/gdkeventsprivate.h
@@ -430,7 +430,7 @@ struct _GdkEventGrabBroken {
* %GDK_DRAG_MOTION or %GDK_DROP_START)
* @surface: the surface which received the event.
* @send_event: %TRUE if the event was sent explicitly.
* @context: the #GdkDragContext for the current DND operation.
* @time: the time of the event in milliseconds.
* @x_root: the x coordinate of the pointer relative to the root of the
* screen, only set for %GDK_DRAG_MOTION and %GDK_DROP_START.
@@ -441,7 +441,7 @@ struct _GdkEventGrabBroken {
*/
struct _GdkEventDND {
GdkEventAny any;
- GdkDragContext *context;
+ GdkDrop *drop;
guint32 time;
gshort x_root, y_root;
@@ -430,7 +430,7 @@ struct _GdkEventGrabBroken {
* @surface: the surface which received the event.
* @send_event: %TRUE if the event was sent explicitly.
- * @context: the #GdkDragContext for the current DND operation.
+ * @drop: the #GdkDrop for the current DND operation.
* @time: the time of the event in milliseconds.
* @x_root: the x coordinate of the pointer relative to the root of the